package com.marakana.yamba;

import winterwell.jtwitter.Twitter;
import android.app.Application;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.preference.PreferenceManager;
import android.util.Log;

public class YambaApplication extends Application implements OnSharedPreferenceChangeListener {
  private static final String TAG = YambaApplication.class.getSimpleName();
  SharedPreferences prefs;
  private Twitter twitter = null;

  @Override
  public void onCreate() {
    super.onCreate();

    prefs = PreferenceManager.getDefaultSharedPreferences(this);
    prefs.registerOnSharedPreferenceChangeListener(this);
  }

  /**
   * Lazily initializes the connection to the online service
   * 
   * @return Twitter object representing connection to online service
   */
  public synchronized Twitter getTwitter() {
    if (twitter == null) {
      // Create twitter object
      String username = prefs.getString("username", "");
      String password = prefs.getString("password", "");
      String server = prefs.getString("server", "");
      twitter = new Twitter(username, password);
      twitter.setAPIRootUrl(server);
      Log.d(TAG, String.format("Getting Twitter with %s/%s@%s", username,
          password, server));
    }
    return twitter;
  }

  // Called when preferences change
  public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
      String key) {
    // Invalidate twitter
    twitter = null;
  }

}
